function  [id, state] = idetcram(iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Get the interval enclosure using Cramer's rule.
%
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... an interval matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   id ... interval enclosure of determinant
%   state ... state of the procedure 'vec' - finite determinant returned
%             'zer' - some x1 contained 0, alg could not be finished
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   Implemented without recursion.
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-01-21    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================


id = infsupdec(1,1);
state = 'vec';

[m, n] = size(iA);

if (m != n)
  error('idetcram: iA is not a square matrix !!!');
end

if (m == 1)
  id = iA(1, 1);
  return;
end

if (m == 2)
   id = iA(1,1) * iA(2, 2) - iA(2, 1) * iA(1, 2); 
   return;
end

for i = m:-1:2
  ib = infsupdec(zeros(i, 1));
  ib(1) = infsupdec(1);
  iC = [ib, iA(:, 2:i)];
  
  [ix, state] = ilshbrenc(iA, ib);
  
  % iA is not H-matrix and possibly even singular
  if (strcmp(state, 'noth'))
    id = infsupdec(-Inf, Inf);
    return;    
  end
  
  % test if 0 in ix, if yes the algorithm can not continue
  if in(0, ix)
    id = infsupdec(-Inf, Inf);
    state = 'zer';
    return;     
  end
  
  id = id / ix(1);

  iA = iA(2:i, 2:i);
end

  id = id * iA(1, 1);
  
end


