function [iD] = idetgersch (iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Get the interval enclosure using Gerchgoring's circles.
%
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... an interval matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iD ... interval enclosure of determinant
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2017-07-10    first version
%   2017-11-17    wrong algorithm correction
%   2017-12-27    tightening the enclosure using a geometric trick 
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================
  
 n = size(iA, 1);
 
 % corresponding nth x, y form a box enclosing the nth Gerschgorin disk
 % x is width
 % y is height radius
 
 diskx = infsupdec(zeros(n, 1));
 diskrad = zeros(n, 1);
 
 % computing enclosing boxes for upper halves of G. disks
 for i=1:n
    rad = sum(mag( iA(i, [1:i-1,i+1:n]) ) );
    diskx(i) = infsupdec( inf(iA(i,i))-rad, sup(iA(i,i)) + rad);
    %diskrad(i) = rad;
 end
 
 % sorting disks along x axis
 [s, indices] = sort(inf(diskx) );
 diskx = diskx(indices);
 %diskrad = diskrad(indices);

 % computing intersections and final determinant
 iD = infsupdec(1,1);
 
 i = 1;
 while i <= n
    diskinf = inf(diskx(i));
    disksup = sup(diskx(i));
    %rad = diskrad(i);
    disknum = 1;
    j = i + 1;
    while j <= n && inf(diskx(j)) < disksup
      
      disksup = max( disksup, sup(diskx(j)));
      %rad = max(rad, diskrad(j));
      disknum = disknum + 1;
      j = j + 1;
    end 
    
    disk = infsupdec(diskinf, disksup);
    
    if disknum == 1
      iD = iD * disk;
    
    elseif subset(0, disk)
       if abs(diskinf) >= abs(disksup)
            if ( mod(disknum, 2) == 1 )
            % odd number of disks in disk
              iD = iD * infsupdec(diskinf^disknum, diskinf^(disknum-1)*disksup); 
            else
                % even number of disks in disk
            iD = iD * infsupdec(diskinf^(disknum-1)*disksup, diskinf^disknum);
            end
       else
          if ( mod(disknum, 2) == 1 )
            % odd number of disks in disk
            iD = iD * infsupdec(disksup^(disknum-1)*diskinf, disksup^disknum); 
          else
            % even number of disks in disk
            iD = iD * infsupdec(disksup^(disknum-1)*diskinf, disksup^disknum);
          end
       end 
    
    elseif diskinf >= 0
      % disk is >= 0
      iD = iD * infsupdec (diskinf^disknum, disksup^disknum);
        
    else
      % disk is <= 0
    
      if ( mod(disknum, 2) == 1 )
        % odd number of disks in disk
        iD = iD * infsupdec(diskinf^disknum, disksup^disknum); 
      else
        % even number of disks in disk
        iD = iD * infsupdec(disksup^disknum, diskinf^disknum);
      end
    
    end
    
    i = j;
 end
  
  
endfunction
