function [id] = idethad (iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Get the interval enclosure using Hadamard's inequality.
%
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... an interval matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iD ... interval enclosure of determinant
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2011  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2019-03-03    first version
%   2019-03-03    rewritten to use both columns and rows in Had. inequality
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================
  

  [m, n] = size(iA);
  
  if (m != n)
    error('idethad: iA must be square');  
  end

  
  % use columns
  v = sqrt( prod( sum( mag(iA).^2 )) );
  id1 = infsupdec(-v, v);
  
  % use rows
  v = sqrt( prod( sum( mag(iA').^2 )) );
  id2 = infsupdec(-v, v);  
  
  id = intersect(id1, id2);
  
  
end