function [ iV ] = ieigbauerfike( iA )
%BEGINDOC=================================================================
% .Author.
%
%  David Riha
%
%-------------------------------------------------------------------------
% .Description.
%
%   Computes enlousure of eigenvectors of n x n interval matrix iA using
%   Bauer and Fike theorem
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  n x n symmetric interval matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iV ... n x 1 interval vector of eigenvalues 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   
%------------------------------------------------------------------------
%  .Licence.
%  
%       
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2017-10-12  first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================

iV = [];
[n, m] = size(iA);

if n ~= m
    warning('Input needs to be square matrix!');
    return
end

Ac = mid(iA);
Ad = rad(iA);

[eigVectors, eigValues] = eig(Ac);

rightSide = norm(eigVectors,2)*norm(inv(eigVectors),2)*norm(Ad,2);
eigValues = diag(eigValues);

for i = 1:size(eigValues)    
    x = midrad(eigValues(i), rightSide);
    iV = [iV; x];
end 

end

