function idiscs = igersch(iA)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Returns verified interval Gerchgoring's circles.
%
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... an interval symmetric matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iD ... interval enclosure of determinant
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-02-07    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================

[m, n] = size(iA);

if (m != n)
  error('igersch: worsks only for square matrices');
end

 diskx = infsupdec(zeros(n, 1));
 diskrad = zeros(n, 1);
 
 % computing enclosing boxes for upper halves of G. disks
 for i=1:n
    rad = sum(mag( iA(i, [1:i-1,i+1:n]) ) );
    diskx(i) = infsupdec( inf(iA(i,i))-rad, sup(iA(i,i)) + rad);
    %diskrad(i) = rad;
 end

idiscs = diskx;


end 