function ubound = l1upperb(iA)

%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Computes verified upper bound on larges eigenvalue of iA
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ... n x n real matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ubound ... verified uper bound on lambda1 of iA
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%  Uses combination of eigsymrohnenc and lambda1(A^S) <= lambda1|A|  
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2017  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-01-14    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%
%ENDDOC===================================================================


% verified upper bound on max eigenvalue of |iA|
eigsAbs = vereigsym(mag(iA));
ubound1 = max(sup(eigsAbs));


%Bound for largest eigenvalue according to Rohn's theorem
lambdas = eigsymencrohn(iA);
len = length(lambdas);
ubound2 = sup(lambdas(len)); 


% minimum of the two previous bounds
ubound = min(ubound1, ubound2);


end