function [solution, discarded, depth] = ilsbabit(initx, epsilon, iA, ib, typeofprune, residual = 0)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Branch and Bound on solution
%
%   The function applies Branch and Bound approach on a interval linear 
%   systems Ax = b (solution). The terminal boxes size is epsilon
%   however it starts with larger boxes, then it makes them smaller 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   initx ... initial framing box before B&B procedure
%   vectors initial box(es) 
%   eps ... the minimum width of the interval that is allowed to divide
%   A ... real matrix  
%   b ... real column vector
%   typeofprune ... the string name of method of prunes for boxes (any method that
%                   returns [pruned box, is unfeasible, is verified] )
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   solution ... boxes that may contain a solution
%   discarded ... boxes that certainly do not contain a solution 
%   depth ... determines the depth in which the box is discarded
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   The boxes we splits into two boxes according to longest side. 
%   untlil the terminal size is reached, the size is halved 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-11-05    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================  


% current epsilon
cureps = max(wid(initx(:, 1))) / 2;


[solution, unknown, discarded] = ilsbab(initx, cureps, iA, ib, typeofprune); 


while cureps > epsilon
  
  [sol, unk, disc] = ilsbab(unknown, cureps, iA, ib, typeofprune); 
  
  solution = [solution, sol];
  unknown = unk;
  discarded = [discarded, disc];
    
  cureps = cureps / 2;  
  
end








end  