function [newbox, flag] = ilsprunebeeck(box, iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%   Jaroslav Horáček
%
%-------------------------------------------------------------------------
% .Description.
%
%  Pruning condition by Beeck's theorem (if iA x \cap ib = empty => no solution)
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   iA ... interval system matrix  
%   ib ... righ-hand side 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   flag ... 0 - verified no solution in a box
%            1 - verified at least one solution
%            2 - verified whole box contain solutions
%            3 - unknown   
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%  
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-31-10    first version
%   2018-11-05    flags used
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================
      
    flag = 3;
      
    if all( ~subset(0, iA * box - ib) )
        flag = 0;
    end
    
    newbox = box;
 
end