function [newbox, flag] = ilsprunejacobi(box, iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%   Adam Szabo
%
%-------------------------------------------------------------------------
% .Description.
%
%   Pruning condition using Gauss-Seidel iteration method.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   iA ... interval matrix of real matrix A  
%   ib ... interval matrix of real column vector b 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   flag ... 0 - verified no solution in a box
%            1 - verified at least one solution
%            2 - verified whole box contain solutions
%            3 - unknown   
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-01-14    first version
%   2018-11-05    flags used
%   2018-11-05    mistakes in conditions corrected
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================

    flag = 3;
    %C = mid(iA);
    %[newbox, state] = ilsgsstep(C\iA, C\ib, box);
    
    [newbox, state] = ilsjacobistep(iA, ib, box);
    
    if strcmp(state, 'non');
       flag = 0;
    end
    
    % Jacobi operator has a fixed point inside
    if (all(interior(newbox, box)))
       flag = 1;
    end  
            
end