function [newbox, flag] = ilspruneoettli(box, iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%   Jaroslav Horáček
%
%-------------------------------------------------------------------------
% .Description.
%
%   Pruning condition by Oettli-Prager theorem for interval linear system
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   iA ... system matrix
%   ib ... system right-hand side
%   
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   flag ... 0 - verified no solution in a box
%            1 - verified at least one solution
%            2 - verified whole box contain solutions
%            3 - unknown        
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%  can also confirm that whole x is in a solution set. Does not contract the 
%  original box.
%  because of speed reasons we switched to flags and not state 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-31-10    first version
%   2018-11-05    flags used
%   2018-11-05    mistakes in conditions corrected
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================
   
    flag = 3;

    [m, n] = size(iA);

    leftside = abs( mid(iA) * box - mid(ib));
    rightside = rad(iA) * abs(box) + rad(ib);   % HERE must be abs not mag !!!!
 
    if any(leftside > rightside)
      flag = 0;
    end  
    
    
    if all( mag(leftside) <= mig(rightside))
        flag = 2;
    end  
        
    newbox = box;
    
end
