function [ix, ver] = ilsq(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes enclosure of LSQ-solution of iA x = ib 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ix ... enclosure of LSQ solution set 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-03-19    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================

ver = 1;

[m, n] = size(iA);

iC = [  eye(m) iA; transpose(iA) zeros(n) ];
id = [ ib; zeros( n,1) ];


ix = iC \ id;
ix = ix((m+1:m+n));


end