function [ix, state] = initkrawczykenc(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes initial enclosure of the solution set by Krawczyk
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  m x n matrix,
%   ib ...  n-dimensional right-hand side vector
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ix ...  init encslosuro of solution set by Krawczyk
%   state ... contains additional info 
%   'vec' if enclosure is finite or unbounded vector
%   'dif' use different method
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   can be used only when inv(Ac) iA is H-matrix
%  Neumaier, Interval methods for systems of equations, 1990
%  this estimation encslosure uses implicitly the preconditioned original system
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-09-24      first version
%   2018-12-10      wrong definition of v corrected
%
%------------------------------------------------------------------------
% .Todo.
%  
%
%ENDDOC===================================================================


state = 'vec';

[m, n] = size(iA);

%
%if (m > n)
%  iA = iA(1:n, 1:n);
%  ib = ib(1:n);
%end

Ac = mid(iA);
C = inv(Ac);
CAcomp = infsupdec(imatcomp(C*iA));


[ish, u, state] = ismmatrix(CAcomp);

if (ish)
  v = CAcomp * u;
  ix = imaxnorm(C*ib, v) * infsupdec(-u, u);
else
  ix = infsupdec(zeros(n, 1));
  state = 'dif';  
end
  


% yet we use simpler and faster version

%iE = eye(n) - 


    
end