function [is, ver] = issolvablelp(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes whether iA x = ib has any subsystem solvable
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   is ... 1 if is solvable (0 is not verified)
%   ver ... 1 if the result is verified
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   computes solution x = pinv(Ac)*bc, and computes the hull of the given 
%   orthant by sign(x) 
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-09-24    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
% add verification
% verified unbounded check?
%
%ENDDOC===================================================================

[m, n] = size(iA);

is = 0;
ver = 0;

maxx = repmat(-Inf, n+1, 1);
minx = repmat(Inf, n+1, 1);

Ac = mid(iA);
Delta = rad(iA);
bc = mid(ib);
delta = rad(ib);

x = pinv(Ac)*bc;

y = sign(x)';

% replace zeros !!!!


% computing hull of orthant given by sign(x)

I = eye(n);
ctype = blanks(2*m + 1);
%ctype(1:m) = 'U';
ctype(1:(2*m)) = 'U';
ctype(2*m+1) = 'L';
vtype = [];
vtype = repmat('C', n+1, 1);
lb = repmat(-Inf, n+1, 1);
lb(n+1) = 0;
ub = repmat(Inf, n+1, 1);


  Dy = diag(y);
   
  DeltaDy = Delta * Dy;
  C = [ Ac - DeltaDy, ones(m, 1); - Ac - DeltaDy, ones(m, 1); y, 0];
  d = [ sup(ib); -mid(ib) + rad(ib) ; 0];
  
  % computing solution
  e = zeros(n+1, 1);
  e(n+1) = 1;
  [x, fmax, status, extra] = glpk(e, C, d, lb, ub, ctype, vtype, -1);

  
 % dual is unfeasible => primal unbounded  
  if (status==11)
     is = 1;
     ver = 0;
  else         
  % check if x satisfies Oettli-Prager  
  x = x(1:n);
  ix = infsupdec(x);
  
  left = abs( Ac * ix - bc );
  right = rad(iA)*mig(ix) + rad(ib);
  
  if (all (left <= right ))
     is = 1;
     ver = 1; 
  end  

end



end