function [uns, ver, u, it] = isunsfcr(iA, ib, iterate)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   computes whether iA x = ib has empty solution set
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%   iterate ... if 1 (default) iterative computation used
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   uns ... 1 if unsolvable 
%   ver ... 1 if the resukt is verified
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%  checks fullcolumn rank of [iA ib]
%  if the matrix has fcr, then the result is verified
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-03-19    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================

if nargin < 3 
  iterate = 1;
end

[m, n] = size(iA);

iC = [iA, ib];

uns = 0;
ver = 0;


if iterate == 1
    [uns, ver, u, it] = ifcr(iC, 1);
else
   [uns, ver, u, it] = ifcr(iC, 0);
end

end