function [iC, id] = tolsq(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   transforms an overdetermined system to square system for lsq solving 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  interval or real matrix 
%   ib ... interval right hand side
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iC ... interval matrix (m+n) x (m+n)
%   id ... interval vector 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%  after solving the new system an solution is found, first n coefficients
%  form an enclosure of the original solution  
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-10-15    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================

[m, n] = size(iA);

if (m < n)
  error('tolsq: transfroms only square and overedetermined systems');
end

if (m == n)
  iC = iA;
  id = ib;  
  return;
end  

iC = [  eye(m) iA; transpose(iA) zeros(n) ];
id = [ ib; zeros( n,1) ];


end