function [ iV ] = imatpoweig( iA, k, option)
%BEGINDOC=================================================================
% .Author.
%
%  David Riha, Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Computes an enclosure k-th power of interval matrix iA using spectral 
%   decomposition id option = 'normal' is used. Computes an enclosure 
%   k-th power of symetric interval iA if input option='sym' is used.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  n x n  real (symmetric) interval matrix
%   k ... natural power of matrix
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iV ... n x n real interval matrix
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   
%------------------------------------------------------------------------
%  .Licence.
%  
%       
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-8-25     first version
%
%------------------------------------------------------------------------
% .Todo.
%   - automatic check for symmetric matrix
%   - what does "real" do
%
%ENDDOC===================================================================

[n, m] = size(iA);
if n ~= m
    warning('Input needs to be square matrix!');
    return
end

%choose method
if exist('option','var')
    if strcmp(option, 'sym')
        [eigvectors, eigvalues] = imateigv(iA, 'sym');
    elseif strcmp(option, 'normal')
        [eigvectors, eigvalues] = imateigv(iA, 'normal');
    else
        warning('Wrong option');
        iV= [];
        return
    end
else 
    [eigvectors, eigvalues] = imateigv(iA, 'normal');
end






if isempty(eigvectors) || isempty(eigvalues)
    iV = [];
    return
end

iV = eigvectors*(diag(eigvalues)^k)*(inv(eigvectors));


% ???
%iV = real(iV);
end

