function iA = imatrandfix (m, n, fixrad, midbounds=[-1,1])
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   This function will generate random sparse interval matrix, with
%   given width, density and sizes.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   m ... number of rows
%   n ... number of columns
%   fixrad ... fixed radius of all intervals
%   midbounds ... 2-array - [a,b] a <= b interval for random midpoints 
%                 if a=b  we get the same midpoints everywhere
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   iA ... a sparse interval matrix
% 
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2017  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2019-03-03    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%   repair generating of sparse matrices
%  
%ENDDOC===================================================================

  if (nargin < 4)
    midbounds = [-1,1];
  end

  if midbounds(1) > midbounds(2)
     error("imatrandfix: Wrong [a,b] bounds for midpoints a >= b");   
  end
  
  
  % computing sparse matrix with given density (Octave functions)
 % A = full(sprand(m, n, density) > 0)
  
  % computing midpoint Amid
  
  if(midbounds(1) == midbounds(2))
    Arand = repmat(midbounds(1), m, n);
  else 
    Arand = (midbounds(2) - midbounds(1)) * rand(m, n);
    Arand = Arand + midbounds(1);  
  end
  
 % Amid = A .* Arand;
  
  % computing matrix of radii
  iA = midrad(Arand, fixrad);
  
end