function plotpilssol(ipk, Ak, bk, A, b, step)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Plots solution set of parametric interval system
%
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   ipk ... column vector of intervals - bounds for parameters
%   Ak ... cellular array of arrays A{1}=[], A{2}=[]
%   bk ... cellular array of column vectors b{1}=, b{2}=
%   A ... real matrix  
%   b ... real column vector
%   step ... step for distance between discrete values from params
%
%------------------------------------------------------------------------
% .Output parameters.
%
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-07-11 first version    
%
%------------------------------------------------------------------------
% .Todo.
%
%ENDDOC===================================================================

[m, n] = size(A);

if nargin < 6
  step = max(wid(ipk)) / 100;
end

%if nargin < 6
%  initx = repmat(infsup(-Inf, Inf), n, 1);
%end


% 2D case

hold on;

if (n == 2)
  paramnum = length(ipk);
  if (paramnum == 1);
    sol = [];
    for p=inf(ipk(1)):step:sup(ipk(1))    
       AA = Ak{1}.* p + A; 
       bb = bk{1}.* p + b;
       x = AA \ bb;
       sol = [sol, x];
    end
    plot(sol(1,:), sol(2,:) ,'-k', 'LineWidth', 2);
  end
  
  
  if (paramnum == 2);
    for p1=inf(ipk(1)):step:sup(ipk(1))    
      sol = [];
      for p2=inf(ipk(2)):step:sup(ipk(2))    
                 
       AA = Ak{1}.* p1 + Ak{2}.* p2 + A; 
       bb = bk{1}.* p1 + bk{2}.* p2 + b;
       x = AA \ bb;
       sol = [sol, x];
      end
      plot(sol(1,:), sol(2,:) ,'-k', 'LineWidth', 2);      
    end
  end


hold off;  
  
  
end




end

