function [ix, state] = oilslsqenc(iA, ib)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   returns an enclosure of a solution set of a system Ax = b using 
%   transforming it to LSQ supersquare system and solving it 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  m x n matrix, if the line is very long then we can
%          wrap it like this 
%   ib ...  n-dimensional vector
%   iterate ... 0 (default )direct method used for finding d, 1 - iterative 
%      search for d 
%   e ... small positive number (default min(min(diam(A))) * 10^(-5))
%   maxit defines maximal number of iteration steps
%   cyclenum ... number of Rs chosen
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ix ... the enclosure of iAx=ib 
%   state ... a string flag
%       'vec' - x is interval vector
%       'dif' - if spectral radius of G is not < 1, use different method
%       'sin' - midpoint matrix might be singular
%       'exc' - iterations number exceeded
%       'nof' - direct method did not find d 
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   to solve super square system uses HBR enc and returns its flags  
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-10-28    first version

%
%------------------------------------------------------------------------
% .Todo.
%
%ENDDOC===================================================================


[m, n] = size(iA);
[iC, id] = tolsq(iA, ib);
[ix, state] = ilshbrenc(iC, id);
ix = ix((m+1):(m+n));



end



