function [G, g] = oilsrohngg(R, x0, Delta, delta, iA, ib)


%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Hor��ek
%
%-------------------------------------------------------------------------
% .Description.
%
%   finds G and g from Rohn enclosure theorem
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   R ... matrix from Rohn method
%   x0 ... vector from Rohn method
%   Delta ... a radius matrix of C from interval system Cx=d
%   delta ... a radius vector of d from interval system Cx=d
%   A ... some matrix contained in C
%   b ... some vector contained in d
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   G ... G from Rohn's theorem
%   g ... g from Rohn's theorem
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   expression of G, g is obvious from further source code
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-01    first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%
%ENDDOC===================================================================

[m,n] = size(iA);

I = eye( n );
G = abs( I - R * iA ) + abs(R) * Delta;
g = abs( R *( iA * x0 - ib )) + abs(R) * (Delta * abs(x0) + delta);

end