function [ix, state, itnum] = oilssubsqenc( iA, ib, it)
%-------------------------------------------------------------------------
% .Description.
%
%   returns enclosure of the solution set of iA x = ib by randomly choosing 
%   square subsystems and computing intersection of their enclosures
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   iA ...  m x n matrix, if the line is very long then we can
%          wrap it like this 
%   ib ...  n-dimensional right-hand side vector
%   it ... number of subsystems to be chosen
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   ix ...  enclosure if the solution of system iA x = ib
%   state ... contains additional info
%   'vec' if enclosure is finite or unbounded vector
%   'non' system has no solution if the estimation was correct
%   itnum ... number of iterations executed (usually before unsolvability is 
%             discovered)
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%   for solving square subsystems hbr method is used 
%
%------------------------------------------------------------------------
%  .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2011-05-01      first version
%
%------------------------------------------------------------------------
% .Todo.
%   
%  -- vybrat vhodnou metodu pro podčtverce -> magnitude? 
%
%ENDDOC===================================================================


itnum = 0;
state = 'vec';
[m, n] = size(iA);  

% wrong dimensions of matrix iA
if ( m < n)
    error('oilsrandsquareenc: bad size of matrix iA, m must be >= n  ');
end

if (nargin < 3)
  % heuristically set the number of subsystems to be chosen
  it = ceil( m / (2*n /3));  
end

sellist = [];

if (it <= 0)
  sellist = nchoosek([1:m], n);
else
  sellist = randnselfromlist([1:m], n, it);
end


%[A, b] = tointval(A, b);

ix = repmat( infsup(-Inf, Inf), n, 1 );

itnum = size(sellist, 1); 

for i = 1:itnum

    sel = sellist(i, :);
    iAsel = iA(sel, :);
    ibsel = ib(sel, :);
        
 % solving square system
    [is, state] = ilshbrenc(iAsel, ibsel);
    
    if(strcmp(state, 'vec') )
      ix  = intersect(ix, is);
      if( any(isempty(ix)) )
          % no solution 
          ix = repmat(NaN, n, 1 );
          state = 'non';
          itnum = i;
          return;
        end
    end
end

end

