function [obox] = boundsol(boxes)
%BEGINDOC=================================================================
% .Author.
%
%  Adam Szabo
%
%-------------------------------------------------------------------------
% .Description.
%
%  Bounds boxes containing solutions and creates one box that encloses all
%  the boxes with solutions - finds a thick outline of the boxes.
%
%-------------------------------------------------------------------------
% .Input parameters.
%
%   boxes ... boxes obtained from B&B procedure  
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   obox ... output box
%  
%------------------------------------------------------------------------
% .Implementation details. 
%  
%  all boxes of sol(input) have the same width and height
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-04-28    first version
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================

  bboxes = transpose(boxes);

  [m, n] = size(boxes);
  c = m*n;
  i = 1;  

  e = boxes(2, 1); % y - height
  o = boxes(1, 1); % x - width
  bsol = [];

  while (i <= c)
    
    if (mod(i,2) == 0) % EVEN (y)
      e = union(e, boxes(i));   
    else % ODD (x)
      o = union(o, boxes(i));
    end
    
    i = i + 1;
    
  end

  obox = [o; e];

end
