function [bsq] = bsqpilsbabonx(bso, nameofpils, typeofprune, limitboundboxes)
%BEGINDOC=================================================================
% .Author.
%
%  Adam Szabo
%
%-------------------------------------------------------------------------
% .Description.
%
%  This function runs the B&B process on a quadrant if it is not too small
%  and returns the new quadrants from the input quadrant.    
%
%-------------------------------------------------------------------------
% .Input parameters.
%
%   bso ... one of the quadrants which contain solutions
%   nameofpils ... name of the parametric interval linear system of the example,
%   from the tests.m function
%   typeofprune ... the name of method of prunes for boxes
%   limitboundboxes ... limitation on the boxes to be bounded
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   bsq ... the new quadrants or the original input quadrants - if it is too small
%  
%------------------------------------------------------------------------
% .Implementation details. 
%  
%  Ideal limitboundboxes depends on the example.
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-19    first version
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================
 
  if((wid(bso)(1)) < limitboundboxes || (wid(bso)(2)) < limitboundboxes  )
    %disp("yes");
    bsq = bso;
  else
    %disp("no");
    
    [initx, pk, Ak, bk, A, b] = tests(nameofpils);
    newsol = pilsbabonx(bso, 0.1, pk, Ak, bk, A, b, typeofprune);
    bsq = boundsolquad(newsol);
    %bsq2 = newsol;
  end

end
