function map = createmap(boxes, initx)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Creates 0/1 bitmap from boxes, assumes the sides of boxes to share common divisor
%
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   boxes ... boxes obtained from B&B procedure
%   initx ... initial framing box before B&B procedure
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   map ... output bit map
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-18    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%  Remove the nasty trick that bypasses adding interval vector to empty array  
%
%ENDDOC===================================================================


  [m, n] = size(boxes);
  
  minxwidth = min(diam(boxes(1,:)));
  minywidth = min(diam(boxes(2,:)));

  xwidth = diam(initx(1));
  ywidth = diam(initx(2));
  
  %width / minwidth
  %height / minheight
  
  mapxwidth = round(xwidth / minxwidth);
  mapywidth = round(ywidth / minywidth);
  
  
  % 1) initialization of bitmap
  map = zeros( mapxwidth, mapywidth );


  % 2) filling bitmap
  for i=1:n 
    %disp('---');
    box = boxes(:, i);
    
    
    
    minx = abs(round( ( inf(box(1)) - inf(initx(1)) ) / minxwidth)) + 1;
    maxx = minx + round(diam(box(1)) / minxwidth ) - 1;

    miny = abs(round( ( inf(box(2)) - inf(initx(2)) ) / minywidth)) + 1;
    maxy = miny + round(diam(box(2)) / minywidth ) - 1; 

    map(minx:maxx, miny:maxy) = 1;
    
  end  
  

end