function newboxes =  mergeboxes(boxes, initx)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%  when we use B&B division according to larger side
%  this procedure merges small children boxes to their parents if they all 
%  are marked as possibly containing solution 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   boxes ... boxes obtained from B&B procedure
%   initx ... initial framing box before B&B procedure
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newboxes ... output new merged boxes
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-18    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%  - Remove the nasty trick that bypasses adding interval vector to empty array  
%  - Implement properly the verification
%
%ENDDOC===================================================================







% NASTY trick :(((( to enable add to empty array ?????

  newboxes = [infsup(1,2); infsup(1,2)];
  
  
  
   minxwidth = min(diam(boxes(1,:)));
   minywidth = min(diam(boxes(2,:)));

   xwidth = diam(initx(1));
   ywidth = diam(initx(2));
  
   mapxwidth = round(xwidth / minxwidth);
   mapywidth = round(ywidth / minywidth);
  
  
  
  % 1) creating a map 
  map = createmap(boxes, initx);
  
  % 2) recursive merging
   stack = [infsup(1,mapxwidth); infsup(1,mapywidth)];
   xwidthstack = [xwidth];
   ywidthstack = [ywidth];
   lastboxindex = 1;
   
   while (lastboxindex > 0)

    %  disp('---');
      box = stack(:, lastboxindex);
      
      
      if( sup(box(1))==inf(box(1)) && sup(box(2))==inf(box(2)) )
        % box is already 1 x 1
        
          if (map( inf(box(1)), inf(box(2))) > 0)
            newboxes = [newboxes, box];    
          end
          lastboxindex = lastboxindex - 1;   
      
      elseif all(all(map(inf(box(1)):sup(box(1)), inf(box(2)):sup(box(2)))))
          % all subboxes contain 1 
          newboxes = [newboxes, box];
          lastboxindex = lastboxindex - 1;    
          
     elseif all(all(map(inf(box(1)):sup(box(1)), inf(box(2)):sup(box(2))) == 0))
          % all subboxes contain 0
          lastboxindex = lastboxindex - 1;        
          
      else
          % divide according to width
          wx = xwidthstack(lastboxindex);
          wy = ywidthstack(lastboxindex);
          if wx >= wy
            boxw = round(diam(box(1)) / 2);
            b1 = [ infsup( inf(box(1)), inf(box(1)) + boxw - 1) ; box(2)];
            b2 = [ infsup( inf(box(1)) + boxw, sup(box(1))) ; box(2)];
       
            stack(:, lastboxindex) = b1;  
            stack(:, lastboxindex + 1) = b2;
            xwidthstack(lastboxindex) = wx / 2; 
            xwidthstack(lastboxindex + 1) = wx / 2;  
            ywidthstack(lastboxindex) = wy;
            ywidthstack(lastboxindex + 1) = wy;
              
          else
          % divide according to height
  
            boxw = round(diam(box(2)) / 2);
            b1 = [ box(1); infsup( inf(box(2)), inf(box(2)) + boxw - 1) ];
            b2 = [ box(1); infsup( inf(box(2)) + boxw, sup(box(2))) ];
            stack(:, lastboxindex) = b1;  
            stack(:, lastboxindex + 1) = b2;
            xwidthstack(lastboxindex) = wx; 
            xwidthstack(lastboxindex + 1) = wx;  
            ywidthstack(lastboxindex) = wy / 2;
            ywidthstack(lastboxindex + 1) = wy / 2;
          
          end 
         
          lastboxindex = lastboxindex + 1;  
              
      
      end  
      
      
   end

   [m, n] = size(newboxes);
   newboxes = newboxes(:, 2:n);
   n = n - 1;
  
  
  % 3) returning merged boxes
  
  
for i=1:n
  box = newboxes(:, i);

  minx = inf(initx(1)) + (inf(box(1)) - 1) * minxwidth;
  maxx = minx + (diam(box(1)) + 1) * minxwidth;
  miny = inf(initx(2)) + (inf(box(2)) - 1) * minywidth;
  maxy = miny + (diam(box(2)) + 1) * minywidth;
  
  newboxes(:, i) = [infsup(minx, maxx); infsup(miny, maxy)];
  
end


  
end