function newboxes =  mergeboxesheu(boxes, initx)
%BEGINDOC=================================================================
% .Author.
%
%  Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%  when we use B&B division according to larger side
%  this procedure merges small children boxes to their parents if they all 
%  are marked as possibly containing solution 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   boxes ... boxes obtained from B&B procedure
%   initx ... initial framing box before B&B procedure
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newboxes ... output new merged boxes
%
%------------------------------------------------------------------------
% .Implementation details. 
%
% it uses simple local search heuristics
%------------------------------------------------------------------------
% .License.
%    Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.   
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-18    first version
%
%------------------------------------------------------------------------
% .Todo.
%
%  - Remove the nasty trick that bypasses adding interval vector to empty array  
%  - Implement properly the verification
%
%ENDDOC===================================================================



% NASTY trick :(((( to enable add to empty array ?????

  newboxes = [infsup(1,2); infsup(1,2)];
  
   minxwidth = min(diam(boxes(1,:)));
   minywidth = min(diam(boxes(2,:)));

  
  % 1) creating a map 
  map = createmap(boxes, initx);
  [mapxwidth, mapywidth] = size(map);
  covered = zeros(mapxwidth, mapywidth);
  
  
  % 2) random merging  
  finished = 0;
  
  while !finished
  
    xs = [];
    ys = [];
  
    % filtering yet unmarked boxes
    for x = 1:mapxwidth  
      for y = 1:mapywidth
        if(map(x,y) == 1 && covered(x,y)==0)
           xs = [xs, x];
           ys = [ys, y];       
        end          
      end      
    end
    
    
    % randomly picking and spreading a box  
   if !isempty(xs)
      l = length(xs);
      choice = randi(l); 
      x = xs(choice);
      y = ys(choice);   
      [box, covered] = spread(x, y, map, covered, mapxwidth, mapywidth);   
      newboxes = [newboxes, box]; 
   else 
      finished = 1;  
   end   

    
  
  end
  
  

   [m, n] = size(newboxes);
   newboxes = newboxes(:, 2:n);
   n = n - 1;
  
  
  % 3) returning real merged boxes  
  for i=1:n
    box = newboxes(:, i);
  
    minx = inf(initx(1)) + (inf(box(1)) - 1) * minxwidth;
    maxx = minx + (diam(box(1)) + 1) * minxwidth;
    miny = inf(initx(2)) + (inf(box(2)) - 1) * minywidth;
    maxy = miny + (diam(box(2)) + 1) * minywidth;
    
    newboxes(:, i) = [infsup(minx, maxx); infsup(miny, maxy)];
    
  end


end




function [box, covered] = spread (x, y, map, covered, mapxwidth, mapywidth)


    minx = x;
    maxx = x;
    miny = y;
    maxy = y;


    goon = 1;
    
    % iteratively tries to enlarge box
    while goon
    
      % 1 - left, 2 - right, 3 - up, 4 - down
      strategies = [];
                            
      % right                      
      if maxx < mapxwidth
        ok = all(all(map(minx:(maxx+1), miny:maxy)) ) && !any(any(covered(minx:(maxx+1), miny:maxy)));
        if(ok)
          strategies = [strategies, 2];
        end
      end           
      
      % down
      if maxy < mapywidth
        ok = all(all(map(minx:maxx, miny:(maxy+1))) ) && !any(any(covered(minx:maxx, miny:(maxy+1))));
        if(ok)
          strategies = [strategies, 4];
        end
      end    
      
      % left
      if minx > 1
        ok = all(all(map((minx-1):maxx, miny:maxy)) ) && !any(any(covered((minx-1):maxx, miny:maxy)));
        if(ok)
          strategies = [strategies, 1];
        end
      end    

      % up
      if miny > 1
        ok = all(all(map(minx:maxx, (miny-1):maxy)) ) && !any(any(covered(minx:maxx, (miny-1):maxy)));
        if(ok)
          strategies = [strategies, 3];
        end
      end    
    
      
      % if it is possible to apply at least one spread strategy go on      
      goon = 0;
      if !isempty(strategies)
        goon = 1;
      
        % randomly choosing a spread strategy
        l = length(strategies);
        p = randperm(l);
        strategies  = strategies(p);
        
        switch strategies(1)
        
        case 1
            minx = minx - 1;
        case 2
            maxx = maxx + 1;  
        case 3
            miny = miny - 1;
        case 4
            maxy = maxy + 1;
        
        endswitch
      
      
      end
           
    end
    covered(minx:maxx, miny:maxy) = 1;
    box = [infsup(minx, maxx); infsup(miny, maxy)];



end
