function [newbox, flag] = pilsprunehladik(box, ipk, Ak, bk, A, b)
%BEGINDOC=================================================================
% .Author.
%
%   Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   Pruning condition by necessary condition for solution of param. system
%   by doc.Mgr.Milan Hladik,PhD.
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   ipk ... column vector of intervals - bounds for parameters
%   Ak ... cellular array of arrays A{1}=[], A{2}=[]
%   bk ... cellular array of column vectors b{1}=, b{2}=
%   A ... real matrix  
%   b ... real column vector 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   flag ... 0 - verified no solution in a box
%            1 - verified at least one solution
%            2 - verified whole box contain solutions
%            3 - unknown  
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-06-29    first version
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================
  
    flag = 3;
  
    [m, n] = size(A);  
    
    paramnum = length(ipk);

    xc = mid(box);
  
    % creating  M(xc) and ip^T
    ip = [infsup(1)];
    M = [A*xc - b];
    for i=1:paramnum    
       ip = [ip, ipk(i)];                   
       M = [M, Ak{i}*xc - bk{i}];                   

    end
  
    k = paramnum + 1; 
  
    cc = [zeros(m, 1); ones(2*k, 1)];
    AA = [M', eye(k), -eye(k); zeros(1, m), sup(ip), -inf(ip)];
    bb = [zeros(k, 1); -1];
    lb = [repmat(-Inf, m, 1); zeros(2*k, 1) ];
    
    ctype = blanks(k+1);
    ctype(1:k) = 'S';
    ctype(k+1) = 'U';
  
    [u, fmin, status, extra] = glpk(cc, AA, bb, lb, [], ctype);
    u = u(1:m);
    
    if (status == 10)
       flag = 3;        
    else 
      
      % creating  M(box)
      M = [A*box - b];
      for i=1:paramnum                      
        M = [M, Ak{i}*box - bk{i}];                   
      end
    
    
     leftside = rad(ip)*mag((M')*u);
     rightside = mid(ip)*((M')*u); 
    %  printf('%f <= %f \n', leftside, inf(rightside));
   



   if (leftside < rightside)    
        flag = 0;    
      end
    end
    newbox = box;
    %unf=0;
 
end

