function [newbox, unf] = prune_fcr(box, ipk, Ak, bk, A, b)
%BEGINDOC=================================================================
% .Author.
%
%   Jaroslav Horacek
%
%-------------------------------------------------------------------------
% .Description.
%
%   It is based on unsolvability detection of ILS using FCR norm condition
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   ipk ... column vector of intervals - bounds for parameters
%   Ak ... cellular array of arrays A{1}=[], A{2}=[]
%   bk ... cellular array of column vectors b{1}=, b{2}=
%   A ... real matrix  
%   b ... real column vector 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   unf ... indicator for intersection, unf = 0 if the intersection is
%   empty otherwise unf = 1
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2017  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-13    first version
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================
  
    [m, n] = size(A); 
    
    iA = infsup(zeros(m, n));
    ib = infsup(zeros(m, 1));
   
    paramnum = length(ipk); 
    unf = 1;
                
    
    % deparametrization => results in an ILS
    for i=1:paramnum    
       iA = iA + ipk(i).*(Ak{i});
       ib = ib + ipk(i).*(bk{i})
    end
    
    
    if(isunsfcr(iA, ib, 0))
       unf = 1;     
    end
    
    
    newbox = box;
    
    %unf=0;
 
end