function [newbox, unf] = prune_intersect2(box, ipk, Ak, bk, A, b)
%BEGINDOC=================================================================
% .Author.
%
%   Adam Szabo
%
%-------------------------------------------------------------------------
% .Description.
%
%   Pruning condition using residual access. 
%
%-------------------------------------------------------------------------
% .Input parameters.
%   
%   box ... column interval vector / matrix of interval column
%   vectors initial boxe(s) 
%   ipk ... column vector of intervals - bounds for parameters
%   Ak ... cellular array of arrays A{1}=[], A{2}=[]
%   bk ... cellular array of column vectors b{1}=, b{2}=
%   A ... real matrix  
%   b ... real column vector 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   newbox ... the new box after pruning the box from input
%   unf ... indicator for intersection, unf = 0 if the intersection is
%   empty otherwise unf = 1
%
%------------------------------------------------------------------------
% .Implementation details. 
%
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2017  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-01-14    first version
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================

    [m, n] = size(A); 
    
    testint = zeros(m, 1); 
    testintL = zeros(m, 1); 
    
    paramnum = length(ipk); 
    unf = 0;  
    
    Apc = zeros(m, 1);
    bpc = zeros(m, 1);
    
    for i=1:paramnum
       Apc = Apc + (mid(ipk(i))).*(Ak{i});
       bpc = bpc + (mid(ipk(i))).*(bk{i});
    end
    
    Apc = Apc + A;
    bpc = bpc + b; 
    
    x_star = Apc \ bpc;
    iy = box - x_star; 
    
    for i=1:paramnum
      testint = testint + ipk(i).*(bk{i} - Ak{i}*x_star);
    end
    
    testint = testint + (b - A*x_star);

    for i=1:paramnum
      testintL = testintL + ipk(i).*(Ak{i});
    end
    
    testintL = testintL + A;
    testintL = testintL*iy;
        
    if any( disjoint(testintL, testint) )
        unf = 1;
    end
    
    newbox = box;    
    %unf=0;
 
end