function [q1,q2,q3,q4] = quadrants(bound)
%BEGINDOC=================================================================
% .Author.
%
%  Adam Szabo
%
%-------------------------------------------------------------------------
% .Description.
%  
%  Splits the input box into the quadrants.
%
%-------------------------------------------------------------------------
% .Input parameters.
%
%   bound ... box contains boxes obtained from the B&B process 
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   q1 ... the first quadrant of the input box
%   q2 ... the second quadrant of the input box
%   q3 ... the third quadrant of the input box
%   q4 ... the fourth quadrant of the input box
%  
%------------------------------------------------------------------------
% .Implementation details. 
%  
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-07    first version
%   2018-06-29    remove the epsilon
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================

  xInterval = bound(1);
  yInterval = bound(2);

  xHalf = mid(xInterval);
  yHalf = mid(yInterval);

  %eps = 0;

  infXint = inf(bound(1));
  supXint = sup(bound(1));

  infYint = inf(bound(2));
  supYint = sup(bound(2));

  % why we need epsilon?
  %q1 = [infsup(xHalf-eps, supXint); infsup(yHalf-eps, supYint)];
  %q2 = [infsup(xHalf-eps, supXint); infsup(infYint, yHalf+eps)];
  %q3 = [infsup(infXint, xHalf+eps); infsup(infYint, yHalf+eps)];
  %q4 = [infsup(infXint, xHalf+eps); infsup(yHalf-eps, supYint)];

  q1 = [infsup(xHalf, supXint); infsup(yHalf, supYint)];
  q2 = [infsup(xHalf, supXint); infsup(infYint, yHalf)];
  q3 = [infsup(infXint, xHalf); infsup(infYint, yHalf)];
  q4 = [infsup(infXint, xHalf); infsup(yHalf, supYint)];

end
