function [s1,s2,s3,s4] = quadsol(boxes)
%BEGINDOC=================================================================
% .Author.
%
%  Adam Szabo
%
%-------------------------------------------------------------------------
% .Description.
%  
%  Split the boxes obtained from the B&B procedure into the quadrants.
%
%-------------------------------------------------------------------------
% .Input parameters.
%
%   boxes ... boxes obtained from B&B procedure
%
%------------------------------------------------------------------------
% .Output parameters.
%
%   s1 ... boxes of sol which belong to the first quadrant
%   s2 ... boxes of sol which belong to the second quadrant
%   s3 ... boxes of sol which belong to the third quadrant
%   s4 ... boxes of sol which belong to the fourth quadrant
%  
%------------------------------------------------------------------------
% .Implementation details. 
%  
%
%------------------------------------------------------------------------
% .Licence.
%  
%   Copyright (C) 2018  Charles University in Prague, Czech Republic
%
%   LIME 1.0 is free for private use and for purely academic purposes. 
%   It would be very kind from the future user of LIME 1.0 to give 
%   reference that this software package has been developed 
%   by at Charles University, Czech Republic.
%
%   For any other use of LIME 1.0 a license is required.
%
%   THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR IMPLIED 
%   WARRANTIES, INCLUDING, WITHOUT LIMITATIONS, THE IMPLIED WARRANTIES 
%   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.    
%    
%-------------------------------------------------------------------------
% .History.
%       
%   2018-05-07    first version   
%
%------------------------------------------------------------------------
% .Todo.
%    
%
%ENDDOC===================================================================

  s1 = [];
  s2 = [];
  s3 = [];
  s4 = [];

  [q1,q2,q3,q4] = quadrants(boundsol(boxes));

  [m, n] = size(boxes);
    
  for i=1:(n)

     box = boxes(:, i); 
     
     int = intersect(box, q1);
     if (all(isempty(int)==0))
       s1 = [s1, int];   
     end
     
     int = intersect(box, q2);
     if (all(isempty(int)==0))
       s2 = [s2, int];   
     end
     
     int = intersect(box, q3);
     if (all(isempty(int)==0))
       s3 = [s3, int];   
     end
     
     int = intersect(box, q4);
     if (all(isempty(int)==0))
       s4 = [s4, int];   
     end
     

  
%    if (subset(inf(boxes(:,i)(1)), q1(1)) && subset(inf(boxes(:,i)(2)), q1(2))) || (subset(sup(boxes(:,i)(1)), q1(1)) && subset(sup(boxes(:,i)(2)), q1(2)))
%      s1 = [s1, boxes(:,i)];
%    
%    elseif (subset(inf(boxes(:,i)(1)), q4(1)) && subset(inf(boxes(:,i)(2)), q4(2))) || (subset(sup(boxes(:,i)(1)), q4(1)) && subset(sup(boxes(:,i)(2)), q4(2)))
%      s4 = [s4, boxes(:,i)];
%    
%    elseif (subset(inf(boxes(:,i)(1)), q2(1)) && subset(inf(boxes(:,i)(2)), q2(2))) || (subset(sup(boxes(:,i)(1)), q2(1)) && subset(sup(boxes(:,i)(2)), q2(2))) 
%      s2 = [s2, boxes(:,i)];
%         
%    elseif (subset(inf(boxes(:,i)(1)), q3(1)) && subset(inf(boxes(:,i)(2)), q3(2))) || (subset(sup(boxes(:,i)(1)), q3(1)) && subset(sup(boxes(:,i)(2)), q3(2))) 
%      s3 = [s3, boxes(:,i)];
%         
%    end     
%      
  end

end
